local _G = getfenv(0);
local AddOn = LibStub("AceAddon-3.0"):GetAddon("EquivalencePoints");
local L = LibStub("AceLocale-3.0"):GetLocale("EquivalencePoints")

local print = function(...) AddOn:PrintFunction(...); end
local debug = function(...) AddOn:DebugFunction(...); end

local pairs, ipairs = pairs, ipairs;
local format = string.format;
local round = AddOn.math_round;

local itemEquipLoc2Slot = {
	INVTYPE_WEAPON = { [16] = 16, [17] = 17 },
	INVTYPE_SHIELD = { [17] = 17 },
	--INVTYPE_2HWEAPON = { [16] = 16 },
	INVTYPE_WEAPONMAINHAND = { [16] = 16 },
	INVTYPE_WEAPONOFFHAND = { [17] = 17 },
	INVTYPE_HOLDABLE = { [17] = 17 },
};

--[[
http://www.wowwiki.com/API_GetItemInfo

http://www.wowwiki.com/ItemEquipLoc
	"INVTYPE_WEAPON"  One-Hand  16,17  
	"INVTYPE_SHIELD"  Shield  17  
	"INVTYPE_2HWEAPON"  Two-Handed  16  
	"INVTYPE_WEAPONMAINHAND"  Main-Hand Weapon  16  
	"INVTYPE_WEAPONOFFHAND"  Off-Hand Weapon  17  
	"INVTYPE_HOLDABLE"  Held In Off-Hand  17
]]

function AddOn:SHAMAN(sItemLink, ItemID, ItemRarity, bonuses, socketBonuses)
	local retVal = self:CreateClassTable(L["EqP Shaman extras:"]);
	local _, _, _, _, _, _, _, _, itemEquipLoc = GetItemInfo(sItemLink);
	
	--[[ Weapon Equivalence Points ]]--
	if (bonuses["WEAPON_SPEED"] and bonuses["WEAPON_MAX"] and bonuses["WEAPON_MIN"]) then
		local dps = round(((bonuses["WEAPON_MAX"] + bonuses["WEAPON_MIN"] ) / 2) / bonuses["WEAPON_SPEED"]);
		local multiplier = bonuses["WEAPON_SPEED"] / 2.6;
		local tilde = (multiplier ~= 1 and L["_tooltip Red Tilde"]) or "";
		
		--// this might need some place where it can be edited but for now this'll do:
		local total, kingsTotal, obeyColor, kingsObeyColor, gemsUsed, kingsGemsUsed = self:Calculate(bonuses, socketBonuses, self.db.profile.Values, ItemRarity);
		local mhaep = dps * 9.03 * multiplier;
		local ohaep = dps * 3.7 * multiplier;
		
		if ((mhaep > 0 or self.db.profile.ShowZero) and itemEquipLoc2Slot[itemEquipLoc] and itemEquipLoc2Slot[itemEquipLoc][16]) then
			self:AddClassLines(retVal, L["_tooltip Main Hand:"], format(L["%s%.2f (%s%.2f)"], tilde, (total + mhaep), tilde, (kingsTotal + mhaep)));
			--self:AddClassLines(retVal, L["_tooltip Main Hand:"], format(L["%.2f%s (%.2f%s)"], (total + mhaep), ((obeyColor and "") or L["_tooltip Ignore Color"]), (kingsTotal + mhaep), ((kingsObeyColor and "") or L["_tooltip Ignore Color"])));
		end
		
		if ((ohaep > 0 or self.db.profile.ShowZero) and itemEquipLoc2Slot[itemEquipLoc] and itemEquipLoc2Slot[itemEquipLoc][17]) then
			self:AddClassLines(retVal, L["_tooltip Off Hand:"], format(L["%s%.2f (%s%.2f)"], tilde, (total + ohaep), tilde, (kingsTotal + ohaep)));
			--self:AddClassLines(retVal, L["_tooltip Off Hand:"], format(L["%.2f%s (%.2f%s)"], (total + ohaep), ((obeyColor and "") or L["_tooltip Ignore Color"]), (kingsTotal + ohaep), ((kingsObeyColor and "") or L["_tooltip Ignore Color"])));
		end
	end
	
	return retVal;
end

function AddOn:ImportEnhancerAEP()
	if (not Enhancer) then print(L["Enhancer not found, import aborted"]); end
	local standardizedData = {};
    
	-- Set new values but don't insert new keys:
	for key, value in pairs(Enhancer.db.profile.AEPNumbers) do
	  standardizedData[key] = value;
	end
	
	self:Import(standardizedData);
end

function AddOn:ImportEnhancerHEP()
	if (not Enhancer) then print(L["Enhancer not found, import aborted"]); end
	local standardizedData = {};
    
	-- Set new values but don't insert new keys:
	for key, value in pairs(Enhancer.db.profile.HEPNumbers) do
	  standardizedData[key] = value;
	end
	
	self:Import(standardizedData);
end

function AddOn:ImportEnhancerDEP()
	if (not Enhancer) then print(L["Enhancer not found, import aborted"]); end
	local standardizedData = {};
    
	-- Set new values but don't insert new keys:
	for key, value in pairs(Enhancer.db.profile.DEPNumbers) do
	  standardizedData[key] = value;
	end
	
	self:Import(standardizedData);
end